mlpy.learners.sklearn package
=============================

.. automodule:: mlpy.learners.sklearn
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.learners.sklearn.auto_wrap
   mlpy.learners.sklearn.base
   mlpy.learners.sklearn.classification
   mlpy.learners.sklearn.regression
